hierarc.Sampling package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hierarc.Sampling.Distributions
   hierarc.Sampling.ParamManager

Submodules
----------

hierarc.Sampling.mcmc\_sampling module
--------------------------------------

.. automodule:: hierarc.Sampling.mcmc_sampling
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hierarc.Sampling
   :members:
   :undoc-members:
   :show-inheritance:
